| Title: | Interactive Feature-Based Analysis of AIRR-Seq Data |
|---|---|
| Description: | An interactive framework for the exploration and analysis of adaptive immune receptor repertoire sequencing (AIRR-seq) data. It enables large-scale computation and integrated analysis of sequence-derived features, including physicochemical properties, amino acid descriptor sets, sequence motifs, compositional patterns, and somatic hypermutation metrics. The application supports multiscale analysis across sequences, clones, and repertoires, with interactive visualizations and statistical feature selection. 'AbSolution' also facilitates reproducible research by enabling structured export of data, code, parameters, and computational environments. See <https://github.com/EDS-Bioinformatics-Laboratory/AbSolution> for more details. |
| Authors: | Rodrigo García-Valiente [cre, aut] (ORCID: <https://orcid.org/0000-0003-0444-5587>, email2: [email protected]), Charisios Triantafyllou [aut] (ORCID: <https://orcid.org/0000-0002-0283-141X>), Antoine van Kampen [aut, ths] (ORCID: <https://orcid.org/0000-0003-1025-7232>) |
| Maintainer: | Rodrigo García-Valiente <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.1 |
| Built: | 2026-06-09 06:06:27 UTC |
| Source: | https://github.com/eds-bioinformatics-laboratory/absolution |
Internally, 'run_app()' calls ['shiny::shinyApp()'] to start the
application, using the UI defined in [app_ui()] and the server
logic defined in [app_server()].
run_app( verbose = FALSE, onStart = NULL, options = list(), enableBookmarking = "server", uiPattern = "/", ... )run_app( verbose = FALSE, onStart = NULL, options = list(), enableBookmarking = "server", uiPattern = "/", ... )
verbose |
Logical. If |
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |
This function is the entry point that end-users should call after installing the package.
if (interactive()) { ### Launch the full application with default settings: run_app() }if (interactive()) { ### Launch the full application with default settings: run_app() }