| Title: | Interactive Feature-Based Analysis of AIRR-Seq Data |
| Version: | 1.0.0 |
| Description: | An interactive framework for the exploration and analysis of adaptive immune receptor repertoire sequencing (AIRR-seq) data. It enables large-scale computation and integrated analysis of sequence-derived features, including physicochemical properties, amino acid descriptor sets, sequence motifs, compositional patterns, and somatic hypermutation metrics. The application supports multiscale analysis across sequences, clones, and repertoires, with interactive visualizations and statistical feature selection. 'AbSolution' also facilitates reproducible research by enabling structured export of data, code, parameters, and computational environments. See https://github.com/EDS-Bioinformatics-Laboratory/AbSolution for more details. |
| License: | GPL (≥ 3) |
| URL: | https://github.com/EDS-Bioinformatics-Laboratory/AbSolution, https://eds-bioinformatics-laboratory.github.io/AbSolution/ |
| BugReports: | https://github.com/EDS-Bioinformatics-Laboratory/AbSolution/issues |
| Depends: | R (≥ 4.4.0) |
| Imports: | alakazam, attachment, benchmarkme, bigassertr, bigparallelr, bigstatsr, Biostrings, bs4Dash, callr, colourpicker, config (≥ 0.3.2), dashboardthemes, data.table, dockerfiler, doParallel, dplyr, DT, foreach, fresh, fs, ggplot2, golem (≥ 0.4.1), grDevices, htmlwidgets, IRanges, iterors, knitr, parallel, Peptides, plotly, pwalign, reactable, rlang, rmarkdown, seqinr, shiny (≥ 1.7.4), shinycssloaders, shinyFiles, shinyjs, shinymanager, shinymeta, shinythemes, shinyWidgets, sortable, stats, stringdist, stringr, sunburstR, tools, umap, upsetjs, utils, viridis, xfun |
| Suggests: | testthat (≥ 3.0.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| Encoding: | UTF-8 |
| Language: | en-US |
| RoxygenNote: | 7.3.3 |
| NeedsCompilation: | no |
| Packaged: | 2026-04-17 09:32:04 UTC; rgarcia |
| Author: | Rodrigo García-Valiente
|
| Maintainer: | Rodrigo García-Valiente <r.garciavaliente@amsterdamumc.nl> |
| Repository: | CRAN |
| Date/Publication: | 2026-04-21 19:22:25 UTC |
Ab_palette: color ranges adapted to the BCR/TCR gene structure
Description
#' @description **Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead. Returns a vector of colors according to the input. For V/D/J/VJ/VDJ inputs, the colors are produced in a way that genes and combination of genes from the same family are assigned a similar color.
Usage
Ab_palette(
list_values,
vect_genes_comb = NA,
type_values = c("V", "D", "J", "VJ", "VDJ", "cuantitative", "cualitative"),
colorblind = FALSE,
seed = 1234
)
Arguments
list_values |
For V(D)J combinations, a list of lists of the families of each segment and the genes within them. For V/D/J segments, a list of the families and the genes within them. For cuantitative or cualitative values, a list of values. |
vect_genes_comb |
The vector of the V(D)J combinations present in the dataset if type_values is 'VJ' or 'VDJ'. Otherwise, NA. |
type_values |
One of 'V','D','J','VJ','VDJ', 'cuantitative' or 'cualitative'. 'V','D','J','VJ','VDJ', |
colorblind |
If TRUE, the output is a colorblind-friendly vector of colors from the viridis package. The similarity of the V-D-J colors is lost. |
Value
palette_colors: a (named) vector of colors
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
2_Feature_determination_1
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
Feature_1(path_base, grouping_by)
Value
The return value, if any, from executing the function.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
2_Feature_determination_2
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
Feature__dataset(
path_base,
DF_to_parse,
name_DF_to_parse,
FWR1partial,
FWR4partial,
standard = TRUE
)
Value
The return value, if any, from executing the function.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
Big PCA
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead. A function to perform PCA over a FBM object.
Usage
big_PCA(FBM, rows, columns)
Arguments
FBM |
A FBM object. |
rows |
Index of rows of the FBM that will be used to calculate the PCA. |
columns |
Index of columns of the FBM that will be used to calculate the PCA.. |
Value
A list with the PCA scores and its explained variances
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
4_Clonal_exploration
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
calculate_clone(
seq_df,
clonotype,
AA_or_NT = "NT",
region = "CDR3",
percentage = 100,
calculate_shared_clones
)
Value
The return value, if any, from executing the utility.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
5_Feature_exploration
Description
A utils function
Usage
draw_feature_violinplot(
values,
name_values,
sequence_info_df,
group_info,
additional_group_info = "Patient",
show_reconstructed,
compare_opposites = FALSE,
selected_rows,
selected_subclones = NULL,
selected_clones = NULL,
hide_dots = FALSE,
really_hide_dots = FALSE,
width = 1400,
height = 1000,
img_type = "png",
scale = 4,
seed = 1234,
source = "feature_violinplot",
primary_color = "#09BC8A"
)
Value
The return value, if any, from executing the utility.
4_Clonal_exploration
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
draw_sharedclonesplot(
seq_df,
sets = NULL,
group = "Patient",
selected_rows,
clonotype,
AA_or_NT = "AA",
region = "CDR3",
percentage = 100,
freq_filter = 0,
Selected_clones = NULL,
dominance_threshold,
color_by = "Clonal sharing",
colorblind,
Big_mem_color_values,
seed = 1234,
width = 1400,
height = 1000,
img_type = "png",
scale = 4
)
Value
The return value, if any, from executing the utility.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
4_Clonal_exploration
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
draw_upsetplot(
seq_df,
group = "Patient",
selected_rows,
clonotype,
AA_or_NT = "AA",
region = "CDR3",
percentage = 100,
freq_filter = 0,
Selected_clones = NULL
)
Value
The return value, if any, from executing the utility.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
4_Clonal_exploration
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
draw_violinplots(
seq_df,
group = "Patient_Sample",
selected_rows,
clonotype,
AA_or_NT = "AA",
region = "CDR3",
percentage = 100,
freq_filter = 0,
Selected_clones = NULL,
dominance_threshold,
seed = 1234,
really_hide_dots = FALSE,
width = 1400,
height = 1000,
img_type = "png",
scale = 4,
source = "clone_violinplot"
)
Value
The return value, if any, from executing the utility.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
3_Data_processing
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
filter_merged(
FBM,
merged_df,
merged_header,
use_rgermline,
use_repertoire,
use_productive,
use_nonproductive,
my_regions,
my_var_elements,
my_vars,
my_vartypes,
use_sharedVDJ,
V_J_to_use,
groups,
group_A,
group_B,
group_C,
univlog = FALSE,
samples_to_keep,
variables_to_remove,
pval_type,
pval_cutoff,
estimate_cutoff,
number_selected_vars,
VJ_deselected,
VDJ_normalized_per_size,
R_mut_threshold_min,
R_mut_threshold_max,
to_compare_groups,
VDJ_maximize_clones,
VDJ_normalized_per_sample,
my_clone_def,
seed,
chains,
igsubtypes
)
Value
The return value, if any, from executing the function.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
Merge FBMs and meta files
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead. A function to join by row individual FBMs and .info files into a unique FBM and a unique .info file, merged_bm.
Usage
merge_FBMs(filepath)
Arguments
filepath |
Path to the individual FBMs. |
Value
A list with the merged FBM, the merged info file and the FBM header.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
1_Parsing
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.
Usage
parse_AIRRSeq_file(
file,
group,
patient,
subgroup,
sample,
input_path,
C_region_included,
FWR1partial,
FWR4partial,
D_gene,
repertoire,
output_path,
is_example = FALSE
)
Value
The return value, if any, from executing the function.
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
Run the AbSolution Shiny Application Launches the interactive AbSolution Shiny application for exploring B-cell and T-cell receptor repertoire data. The application provides tools for loading AIRR-formatted datasets, inspecting sequence characteristics, visualizing clonotype distributions, and generating summary reports.
Description
Internally, 'run_app()' calls ['shiny::shinyApp()'] to start the
application, using the UI defined in [app_ui()] and the server
logic defined in [app_server()].
Usage
run_app(
verbose = FALSE,
onStart = NULL,
options = list(),
enableBookmarking = "server",
uiPattern = "/",
...
)
Arguments
verbose |
Logical. If |
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |
Details
This function is the entry point that end-users should call after installing the package.
Examples
if (interactive()) {
### Launch the full application with default settings:
run_app()
}
Check parameters in 3. are properly selected
Description
**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead. A function to perform PCA over a FBM object.
Usage
validate_before_run(
work_as_categories,
use_sharedVDJ,
VJ_included,
VDJ_maximize_clones,
clonal_group
)
Examples
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.